#!/bin/bash 

## This script will verify the existance (or non-existance) of the file $HOME/.config/autostart/ncl_autologin.desktop 
## so that the display manager will execute the application "/opt/novell/ncl/bin/ncl_autologin" when the
## display manager is fully initialized, and starting other desktop applications.
## The above file should only exist if the admin and user settings are correct to enable the Novell Integrated Login
## otherwise this script will remove the desktop startup file from the user $HOME area

## Instructions:
## normal usage is: "novell-ncl-autologin.sh"
## realtime debug is: "novell-ncl-autologin.sh debug"
## to START "startup debug tracing" is: "novell-ncl-autologin.sh debug start" (output to file novell-client-starup.debug at startup)
## to STOP  "startup debug tracing" is: "novell-ncl-autologin.sh debug stop"  (terminate any futher debug, by deleting the debug output file)

DEBUG=
TEMP_DEBUG_OUT="$HOME/novell-client-startup.debug"

if [ ! -z $1  ]; then

   if [ `echo $1` == "debug" ]; then
      DEBUG=1
      DEBUG_OUT=

      if [ ! -z $2  ]; then
         DEBUG_OUT=$TEMP_DEBUG_OUT
         if [ `echo $2` == "start" ]; then
           echo "novell-ncl-autologin debug STARTED.  Output sent to $DEBUG_OUT"
           #erase contents of debug file
           >$DEBUG_OUT

##### create autostart config for display manager, and simple script, to document when display manager is running autostart apps
##### this is useful to tell if display manager could test for my config, before it was written to autostart directory
##            echo "adding $HOME/.config/autostart/novell-client-debug-hack.sh"
##cat >$HOME/.gnome2/session-manual 2>&1 <<-END1
##echo "xxxxx desktop startup was run at `date +%a_%b_%d_%Y_%H:%M:%S.%N` xxxxx | tee -a $DEBUG_OUT"
##END1

         elif [ `echo $2` == "stop" ]; then
           echo "novell-ncl-autologin debug terminated.  File $DEBUG_OUT has been removed."
           #erase contents of debug file
           rm -f $TEMP_DEBUG_OUT
           echo "Exiting, without running any other contents."
           exit 0
         else
           echo "ERROR. Invalid option.  Options must be either 'debug' or 'debug start' or 'debug stop'"
           echo "Exiting."
           exit 0
         fi
      fi
# commented out, since autobuild starts this with a "-qf"
#   else
#      echo "ERROR. Invalid option ($1).  Options must be either 'debug' or 'debug start' or 'debug stop'"
#      echo "Exiting."
#      exit 0
   fi

## end of testing for arguments
else
# if my debug file exists, then concat contexts to it
    if [ -f "$TEMP_DEBUG_OUT" ]; then
      DEBUG_OUT=$TEMP_DEBUG_OUT
      DEBUG=1
    fi
fi

# YaST Configuration file
SYS_LOGIN="/etc/opt/novell/ncl/login.conf"
CONF_STARTUP="`echo $HOME`/.novell/ncl/StartupLogin.conf"
CONF_MAPS="`echo $HOME`/.novell/ncl/StartupMaps.conf"
DEBUG_OPTION=""

# desktop file for KDE autostart
AUTOSTART="ncl_autologin.desktop"
SOURCELNK="/opt/novell/ncl/bin/$AUTOSTART"
DESTLNK="$HOME/.config/autostart/$AUTOSTART"

#### DISPLAY DEBUG BANNER #####
if [ $DEBUG ]; then 
   if [ $DEBUG_OUT ]; then 
     echo "" | tee -a $DEBUG_OUT
     echo "Debug output also writted to $DEBUG_OUT"
   fi
   echo "--== output from novell-ncl-autologin.sh date=`date +%a_%b_%d_%Y_%H:%M:%S.%N` =--" | tee -a $DEBUG_OUT
fi

# HOME must be defined
if [ -z `echo $HOME` ]; then
  echo "Error: \$HOME not defined"  | tee -a $DEBUG_OUT
  exit
fi

if [ $DEBUG ]; then 
   echo "Current state of $DESTLNK" | tee -a $DEBUG_OUT
   ls -al $DESTLNK | tee -a $DEBUG_OUT
fi

# setting up PATH variable
if [ -z `echo $PATH | grep "/opt/novell/ncl/bin"` ]; then
    export PATH="$PATH:/opt/novell/ncl/bin"
fi

########################
## disable_autostart()
########################
disable_autostart() {
if [ $DEBUG ]; then 
   echo "-- disable Novell integrated login when display manager starts ---"  | tee -a $DEBUG_OUT
   DEBUG_OPTION="-v"
fi
# Remove the GNOME/KDE autostart desktop file
if [ -f "$DESTLNK" ]; then
   rm -f $DEBUG_OPTION $DESTLNK
fi

if [ $DEBUG ]; then 
  echo "ncl_autologin disabled at `date +%a_%b_%d_%Y_%H:%M:%S.%N`"  | tee -a $DEBUG_OUT
fi

} ## end disable_autostart ##

########################
## enable_autostart()
########################
enable_autostart(){
if [ $DEBUG ]; then 
  echo "-- enable Novell integrated login when display manager starts ---"  | tee -a $DEBUG_OUT
  DEBUG_OPTION="-v"
fi
# GNOME/KDE autostart
mkdir -p $DEBUG_OPTION $HOME/.config/autostart
if [ -d "$HOME/.config/autostart" ]; then
   #if autostart file not there, then copy it there
#   if [ ! -f "$DESTLNK" ]; then
      if [ $DEBUG ]; then 
         echo "copy NCL autostart desktop file into autostart directory"  | tee -a $DEBUG_OUT
      fi
      cp -f $DEBUG_OPTION $SOURCELNK $DESTLNK
#   else
#      if [ $DEBUG ]; then 
#         echo "NCL autostart already exists.  do nothing"  | tee -a $DEBUG_OUT
#      fi
#   fi
fi

if [ $DEBUG ]; then 
  echo "ncl_autologin enabled at `date +%a_%b_%d_%Y_%H:%M:%S.%N`"  | tee -a $DEBUG_OUT
fi

} ## end enable_autostart ##

########################
## main()  continued....
########################
# insert excludeApps
if [ ! -f "$HOME/.kde/share/config/ksmserverrc" ]; then
    mkdir -p $HOME/.kde/share/config
    touch $HOME/.kde/share/config/ksmserverrc
fi

if [ `grep '\[General\]' $HOME/.kde/share/config/ksmserverrc | wc -l` -eq 0 ]; then
    echo -e "\n[General]" >> $HOME/.kde/share/config/ksmserverrc
    echo "excludeApps=ncl_autologin" >> $HOME/.kde/share/config/ksmserverrc
else
    if [ `grep 'excludeApps' $HOME/.kde/share/config/ksmserverrc | wc -l` -eq 0 ]; then
	    perl -pi -e "s|\[General\]|\[General\]\nexcludeApps=ncl_autologin|" $HOME/.kde/share/config/ksmserverrc
    else
	    if [ `grep '^excludeApps=.*ncl_autologin' $HOME/.kde/share/config/ksmserverrc | wc -l` -eq 0 ]; then
	      perl -pi -e 's|excludeApps=(.*)|excludeApps=ncl_autologin:$1|' $HOME/.kde/share/config/ksmserverrc
	    fi
    fi
fi

OK="no"

#test if global config file exists, if not, the default is to run integrated login
if [ -f $SYS_LOGIN ]; then
   # did we specifically find the line to not run?
	if [ `grep -i 'Allow_Integrated_Login[ \t]*=[ \t]*false' $SYS_LOGIN | grep -v "^#" | wc -l` -gt 0 ]; then
      # global setting does not allow autologin
      OK="no"
   else
      # global file exists, and not specifically denied
      if [ $DEBUG ]; then 
         echo "admin allows autologin"  | tee -a $DEBUG_OUT
      fi
      OK="yes"
	fi
fi

if [ $DEBUG ]; then 
   if [ $OK == "no" ]; then 
      echo "admin does NOT allow autologin"  | tee -a $DEBUG_OUT
   fi
fi


# default LOCAL setting in the config file (if not there) is 'off'
#if [ $OK == "yes" ]; then
#   OK="no"
   if [ -f $CONF_STARTUP ]; then
         if [ $DEBUG ]; then 
            echo "'$CONF_STARTUP' exist"  | tee -a $DEBUG_OUT
         fi
         OK="yes"
   else
       OK="no"
   	if [ $DEBUG ]; then 
 	     if [ $OK == "no" ]; then 
        	 echo "'$CONF_STARTUP' does NOT exist autologin failed"  | tee -a $DEBUG_OUT
	     fi
   	fi
   fi   
#fi

if [ -f $CONF_MAPS ]; then
   if [ $DEBUG ]; then 
     echo "File '$CONF_MAPS' was FOUND, so run autostart (to authenticate for map commands)"  | tee -a $DEBUG_OUT
   fi
   OK="yes"
else
   if [ $DEBUG ]; then 
     echo "File '$CONF_MAPS' was -NOT- FOUND."  | tee -a $DEBUG_OUT
   fi
fi

#Single Sign On Changes - Call ncl_autologin if Allow_PAM_SSO is set to true
if [ -f $SYS_LOGIN ]; then
        if [ `grep -i 'Allow_PAM_SSO[ \t]*=[ \t]*true' $SYS_LOGIN | grep -v "^#" | wc -l` -gt 0 ]; then
      		OK="yes"
	fi
fi

if [ $DEBUG ]; then 
  echo "run ncl_autologin = $OK"  | tee -a $DEBUG_OUT
fi

if [ $HOME != "/root" ]; then
   if [ $OK == "yes" ]; then
      if [ $DEBUG ]; then 
         echo "calling enable_autostart"
      fi
      enable_autostart
   else
      if [ $DEBUG ]; then 
         echo "calling disable_autostart"
      fi
      disable_autostart
   fi
else
   if [ $DEBUG ]; then 
     echo "run ncl_autologin disabled for root user.  time `date`"  | tee -a $DEBUG_OUT
   fi
fi

